@@ -18,6 +18,7 @@ Classes to interface to devices which communicate using the ThorLabs APT protoco
 """
 
 from .aptdevice import *
-from .aptdevice_dc import *
+from .aptdevice_motor import *
 from .tdc001 import *
 from .bbd import *
+from .bsc import *
